BlendRecipe: Combining recipes from different tables
====================================================

The BlendRecipe extension lets you combine data from multiple recipes.


.. module:: recipe

.. autoclass:: BlendRecipe
    :members: blend,full_blend
    :noindex: 
